pub enum Address {
Address0,
Address1,
Address2,
Address3,
Broadcast,
}Expand description
I2C address used to address the device.
Variants
Address0
Devices configured with GND, GND on addr0 and addr1.
Address1
Devices configured with GND, VCC on addr0 and addr1.
Address2
Devices configured with VCC, GND on addr0 and addr1.
Address3
Devices configured with VCC, VCC on addr0 and addr1.
Broadcast
Broadcast address to address all similar devices on the I2C bus.
Is only valid if all devices would respond to the same commands in a similar way. In other words: if all devices are configured identically.