Config

Struct Config 

pub struct Config {
    pub log_scale: bool,
    pub power_save: bool,
    pub pwm_dithering: bool,
    pub max_current: MaxCurrentOption,
}
Generic configuration for an LP50xx device.

Fields

log_scale: bool

Use logarithmic scaling.

power_save: bool

Turn IC automatically into power save mode when all LEDs are effectively off (after 30ms).

pwm_dithering: bool

Enable dithering mode, stretching the resolution from 9 bits to 12 bits.

max_current: MaxCurrentOption

The maximum amount of current for a single LED channel.

35mA only valid when Vcc >= 3.3V.