Driver

Struct Driver 

pub struct Driver<VARIANT: LP50xx, T: I2c, STATE: Marker> { /* private fields */ }
High level generic driver for the LP50xx family of devices.

See LP50xx on how to instantiate the device.

The channels can be configured per OUT and per RGB LED. Bank-mode is not (yet) supported.

Implementations

Source

impl<VARIANT: LP50xx, T: I2c> Driver<VARIANT, T, Standby>

pub async fn enable( self, ) -> Result<Driver<VARIANT, T, Normal>, DeviceError<T::Error>>

Enable the device, turning on the constant current sinks (if any are configured to have a non-zero duty cycle).

This will consume up to 10mA of current, unless power saving is enabled.

Source

impl<VARIANT: LP50xx, T: I2c> Driver<VARIANT, T, Normal>

pub async fn disable( self, ) -> Result<Driver<VARIANT, T, Standby>, DeviceError<T::Error>>

Disable the device, putting it into Standby mode.

All register values will be retained, but the constant current sinks will no longer be functional, turning off the LEDs.

Consumes up to 12uA of current, depending on the device type.

Source

impl<VARIANT: LP50xx, T: I2c, MARKER: Marker> Driver<VARIANT, T, MARKER>

pub async fn configure( &mut self, config: &Config, ) -> Result<(), DeviceError<T::Error>>

Set the general configuration parameters of the device.

pub async fn set_channel( &mut self, channel_i: u8, value: u8, ) -> Result<(), Error<T::Error>>

Set the specific OUT channel to a specific color value.

Will return the Error::Index if the device does not have the indexed channel.

pub async fn set_rgb( &mut self, rgb_i: u8, value: impl Into<Rgb>, ) -> Result<(), Error<T::Error>>

Set the RGB LED color values.

Will return the Error::Index if the device does not have the indexed RGB LED.

pub async fn set_rgb_brightness( &mut self, rgb_i: u8, value: u8, ) -> Result<(), Error<T::Error>>

Set the brightness of a RGB LED (not the color).

Will return the Error::Index if the device does not have the indexed RGB LED

pub async fn set_all_brightness( &mut self, value: u8, ) -> Result<(), Error<T::Error>>

Set the brightness of all RGB LEDs (not the color) in one call.