pub struct Config {
pub log_scale: bool,
pub power_save: bool,
pub pwm_dithering: bool,
pub max_current: MaxCurrentOption,
}Expand description
Generic configuration for an LP50xx device.
Fields
log_scale: boolUse logarithmic scaling.
power_save: boolTurn IC automatically into power save mode when all LEDs are effectively off (after 30ms).
pwm_dithering: boolEnable dithering mode, stretching the resolution from 9 bits to 12 bits.
max_current: MaxCurrentOptionThe maximum amount of current for a single LED channel.
35mA only valid when Vcc >= 3.3V.